@@ -26,6 +26,8 @@ class InputFtpList(object):
           use-ssl: <yes/no>
           encoding: <auto/utf8/ascii>
           files-only: <yes/no>
+          recursive: <yes/no>
+          get-size: <yes/no>
         dirs:
           - <directory 1>
           - <directory 2>
@@ -46,7 +48,8 @@ class InputFtpList(object):
                     'use-ssl': {'type': 'boolean', 'default': False},
                     'encoding': {'type': 'string', 'enum': encodings, 'default': 'auto'},
                     'files-only': {'type': 'boolean', 'default': False},
-                    'recursive': {'type': 'boolean', 'default': False}
+                    'recursive': {'type': 'boolean', 'default': False},
+                    'get-size': {'type': 'boolean', 'default': True}
                 },
                 'additionProperties': False,
                 'required': ['name', 'username', 'password', 'host', 'port'],
@@ -78,6 +81,7 @@ class InputFtpList(object):
         encoding = connection_config['encoding']
         files_only = connection_config['files-only']
         recursive = connection_config['recursive']
+        get_size = connection_config['get-size']
         mlst_supported = False
 
         feat_response = ftp.sendcmd('FEAT').splitlines()
@@ -105,26 +109,20 @@ class InputFtpList(object):
             baseurl = "ftp://%s:%s@%s:%s/" % (connection_config['username'], connection_config['password'],
                                               connection_config['host'], connection_config['port'])
 
-            self._handle_path(entries, ftp, baseurl, path, mlst_supported, files_only, recursive, encoding)
+            self._handle_path(entries, ftp, baseurl, path, mlst_supported, files_only, recursive, get_size, encoding)
 
         return entries
 
     def _handle_path(self, entries, ftp, baseurl, path='', mlst_supported=False, files_only=False, recursive=False,
-                     encoding=None):
-        try:
-            dirs = ftp.nlst(path)
-        except ftplib.error_perm as e:
-            raise plugin.PluginWarning(str(e))
-
-        if not dirs:
-            log.verbose('Directory %s is empty', path)
+                     get_size=True, encoding=None):
+        dirs = self.list_directory(ftp, path)
 
         for p in dirs:
             if encoding:
                 p = p.decode(encoding)
 
-	    #Clean file list when subdirectories are used
-	    p = p.replace(path + '/', '')
+            #Clean file list when subdirectories are used
+            p = p.replace(path + '/', '')
 
             mlst = {}
             if mlst_supported:
@@ -132,32 +130,32 @@ class InputFtpList(object):
                 clean_mlst_output = [line.strip().lower() for line in mlst_output.splitlines()][1]
                 mlst = self.parse_mlst(clean_mlst_output)
             else:
-            	element_is_directory = self.is_directory(ftp, path + '/' + p)
-            	if element_is_directory:
-            	     mlst['type'] = 'dir'
-            	     log.debug('%s is a directory', p)
-            	else:
-            	    mlst['type'] = 'file'
-            	    log.debug('%s is a file', p)
+                element_is_directory = self.is_directory(ftp, path + '/' + p)
+                if element_is_directory:
+                    mlst['type'] = 'dir'
+                    log.debug('%s is a directory', p)
+                else:
+                    mlst['type'] = 'file'
+                    log.debug('%s is a file', p)
 
             if recursive and mlst.get('type') == 'dir':
                 self._handle_path(entries, ftp, baseurl, path + '/' + p, mlst_supported, files_only,
-                                                 recursive, encoding)
+                                  recursive, get_size, encoding)
 
             if not files_only or mlst.get('type') == 'file':
                 url = baseurl + path + '/' + p
-		url = url.replace(' ', '%20')
+                url = url.replace(' ', '%20')
                 title = os.path.basename(p)
                 log.info('Accepting entry "%s" [%s]' % (path + '/' + p, mlst.get('type') or "unknown",))
                 entry = Entry(title, url)
-                if not 'size' in mlst:
+                if get_size and not 'size' in mlst:
                     if mlst.get('type') == 'file':
-                    	entry['content_size'] = ftp.size(path + '/' + p) / (1024 * 1024)
-                    	log.debug('(FILE) Size = %s', entry['content_size'])
+                        entry['content_size'] = ftp.size(path + '/' + p) / (1024 * 1024)
+                        log.debug('(FILE) Size = %s', entry['content_size'])
                     elif mlst.get('type') == 'dir':
                         entry['content_size'] = self.get_folder_size(ftp, path, p)
-                    	log.debug('(DIR) Size = %s', entry['content_size'])
-                else:
+                        log.debug('(DIR) Size = %s', entry['content_size'])
+                elif get_size:
                     entry['content_size'] = float(mlst.get('size')) / (1024 * 1024)
                 entries.append(entry)
         
@@ -174,18 +172,33 @@ class InputFtpList(object):
             ftp.cwd(elementpath)
             ftp.cwd(original_wd)
             return True
-        except:
+        except ftplib.error_perm:
             return False
 
+    def list_directory(self, ftp, path):
+        try:
+            dirs = ftp.nlst(path)
+        except ftplib.error_perm as e:
+            # ftp returns 550 on empty dirs
+            if str(e).startswith('550 '):
+                log.debug('Directory %s is empty.', path)
+                dirs = []
+            else:
+                raise plugin.PluginError(e)
+        return dirs
+
     def get_folder_size(self, ftp, path, p):
-	size = 0
-	for filename in ftp.nlst(path + '/' + p):
+        size = 0
+        dirs = self.list_directory(ftp, path + '/' + p)
+
+        for filename in dirs:
             filename = filename.replace(path + '/' + p + '/', '')
-	    try:
-	         size += ftp.size(path + '/' + p + '/' + filename) / (1024 * 1024)
-	    except:
-		 size += self.get_folder_size(ftp, path + '/' + p, filename)
-	return size
+            try:
+                size += ftp.size(path + '/' + p + '/' + filename) / (1024 * 1024)
+            except ftplib.error_perm:
+                size += self.get_folder_size(ftp, path + '/' + p, filename)
+        return size
+
 
 @event('plugin.register')
 def register_plugin():
