@@ -13,11 +13,11 @@ from flexget.utils.search import torrent_availability, normalize_unicode
 
 log = logging.getLogger('piratebay')
 
-CUR_TLD = "se"
-TLDS = "com|org|sx|ac|pe|gy|%s" % CUR_TLD
+CUR_TLD = 'to'
+TLDS = 'com|org|sx|ac|pe|gy|se|%s' % CUR_TLD
 
-URL_MATCH = re.compile("^http://(?:torrents\.)?thepiratebay\.(?:%s)/.*$" % TLDS)
-URL_SEARCH = re.compile("^http://thepiratebay\.(?:%s)/search/.*$" % TLDS)
+URL_MATCH = re.compile('^http://(?:torrents\.)?thepiratebay\.(?:%s)/.*$' % TLDS)
+URL_SEARCH = re.compile('^http://thepiratebay\.(?:%s)/search/.*$' % TLDS)
 
 CATEGORIES = {
     'all': 0,
